@@ -474,6 +474,9 @@ class SignalContainer(np.ndarray):
 
     def _check_x_axis_spacing(self, label='requested operation'):
         if self._nonstandard_x_axis is not None:
-            if np.unique(np.diff(self._nonstandard_x_axis)).size > 1:
+            u = np.unique(np.diff(self._nonstandard_x_axis)).size
+            m = np.median(u)
+
+            if (np.abs(u - m) > 10*np.finfo(u.dtype).resolution).any():
                 raise ValueError(f"Cannot perform {label} on an array of non-equally spaced samples")
 
